imxExtractSlot: imxExtractSlot

View source: R/MxBaseNamed.R

imxExtractSlotR Documentation

imxExtractSlot

Description

Checks for and extracts a slot from the object This is an internal function exported for those people who know what they are doing.

Usage

imxExtractSlot(x, name)

Arguments

x

The object

name

the name of the slot


OpenMx documentation built on March 8, 2026, 9:07 a.m.