imxHasWLS: imxHasWLS

View source: R/MxFitFunctionWLS.R

imxHasWLSR Documentation

imxHasWLS

Description

This is an internal function exported for those people who know what they are doing. This function checks if a model uses a fitfunction with WLS units.

Usage

imxHasWLS(model)

Arguments

model

model


OpenMx documentation built on March 8, 2026, 9:07 a.m.