imxUntitledName: imxUntitledName

View source: R/MxUntitled.R

imxUntitledNameR Documentation

imxUntitledName

Description

This is an internal function exported for those people who know what they are doing.

Usage

imxUntitledName()

Details

Returns a character, the name of the next untitled entity


OpenMx documentation built on March 8, 2026, 9:07 a.m.